==> esp8266-0.4.0.crate: esp8266-0.4.0/src/spi0/spi_ext0.rs <==
#[doc = "Register `SPI_EXT0` reader"]
pub struct R(crate::R<SPI_EXT0_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SPI_EXT0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SPI_EXT0_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SPI_EXT0_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SPI_EXT0` writer"]
pub struct W(crate::W<SPI_EXT0_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SPI_EXT0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SPI_EXT0_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SPI_EXT0_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `pp_enable` reader - "]
pub struct PP_ENABLE_R(crate::FieldReader<bool, bool>);
impl PP_ENABLE_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        PP_ENABLE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PP_ENABLE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `pp_enable` writer - "]
pub struct PP_ENABLE_W<'a> {
    w: &'a mut W,
}
impl<'a> PP_ENABLE_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
        self.w
    }
}
#[doc = "Field `pp_shift` reader - "]
pub struct PP_SHIFT_R(crate::FieldReader<u8, u8>);
impl PP_SHIFT_R {
    #[inline(always)]
    pub(crate) fn new(bits: u8) -> Self {
        PP_SHIFT_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PP_SHIFT_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `pp_shift` writer - "]
pub struct PP_SHIFT_W<'a> {
    w: &'a mut W,
}
impl<'a> PP_SHIFT_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x0f << 16)) | ((value as u32 & 0x0f) << 16);
        self.w
    }
}
#[doc = "Field `pp_time` reader - "]
pub struct PP_TIME_R(crate::FieldReader<u16, u16>);
impl PP_TIME_R {
    #[inline(always)]
    pub(crate) fn new(bits: u16) -> Self {
        PP_TIME_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PP_TIME_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `pp_time` writer - "]
pub struct PP_TIME_W<'a> {
    w: &'a mut W,
}
impl<'a> PP_TIME_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x0fff) | (value as u32 & 0x0fff);
        self.w
    }
}
impl R {
    #[doc = "Bit 31"]
    #[inline(always)]
    pub fn pp_enable(&self) -> PP_ENABLE_R {
        PP_ENABLE_R::new(((self.bits >> 31) & 0x01) != 0)
    }
    #[doc = "Bits 16:19"]
    #[inline(always)]
    pub fn pp_shift(&self) -> PP_SHIFT_R {
        PP_SHIFT_R::new(((self.bits >> 16) & 0x0f) as u8)
    }
    #[doc = "Bits 0:11"]
    #[inline(always)]
    pub fn pp_time(&self) -> PP_TIME_R {
        PP_TIME_R::new((self.bits & 0x0fff) as u16)
    }
}
impl W {
    #[doc = "Bit 31"]
    #[inline(always)]
    pub fn pp_enable(&mut self) -> PP_ENABLE_W {
        PP_ENABLE_W { w: self }
    }
    #[doc = "Bits 16:19"]
    #[inline(always)]
    pub fn pp_shift(&mut self) -> PP_SHIFT_W {
        PP_SHIFT_W { w: self }
    }
    #[doc = "Bits 0:11"]
    #[inline(always)]
    pub fn pp_time(&mut self) -> PP_TIME_W {
        PP_TIME_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_ext0](index.html) module"]
pub struct SPI_EXT0_SPEC;
impl crate::RegisterSpec for SPI_EXT0_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [spi_ext0::R](R) reader structure"]
impl crate::Readable for SPI_EXT0_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [spi_ext0::W](W) writer structure"]
impl crate::Writable for SPI_EXT0_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SPI_EXT0 to value 0"]
impl crate::Resettable for SPI_EXT0_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.6.0.crate: esp8266-0.6.0/src/spi0/spi_ext0.rs <==
#[doc = "Register `SPI_EXT0` reader"]
pub struct R(crate::R<SPI_EXT0_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SPI_EXT0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SPI_EXT0_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SPI_EXT0_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `SPI_EXT0` writer"]
pub struct W(crate::W<SPI_EXT0_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<SPI_EXT0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<SPI_EXT0_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<SPI_EXT0_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `pp_enable` reader - "]
pub struct PP_ENABLE_R(crate::FieldReader<bool, bool>);
impl PP_ENABLE_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        PP_ENABLE_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PP_ENABLE_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `pp_enable` writer - "]
pub struct PP_ENABLE_W<'a> {
    w: &'a mut W,
}
impl<'a> PP_ENABLE_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
        self.w
    }
}
#[doc = "Field `pp_shift` reader - "]
pub struct PP_SHIFT_R(crate::FieldReader<u8, u8>);
impl PP_SHIFT_R {
    #[inline(always)]
    pub(crate) fn new(bits: u8) -> Self {
        PP_SHIFT_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PP_SHIFT_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `pp_shift` writer - "]
pub struct PP_SHIFT_W<'a> {
    w: &'a mut W,
}
impl<'a> PP_SHIFT_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x0f << 16)) | ((value as u32 & 0x0f) << 16);
        self.w
    }
}
#[doc = "Field `pp_time` reader - "]
pub struct PP_TIME_R(crate::FieldReader<u16, u16>);
impl PP_TIME_R {
    #[inline(always)]
    pub(crate) fn new(bits: u16) -> Self {
        PP_TIME_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for PP_TIME_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `pp_time` writer - "]
pub struct PP_TIME_W<'a> {
    w: &'a mut W,
}
impl<'a> PP_TIME_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u16) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x0fff) | (value as u32 & 0x0fff);
        self.w
    }
}
impl R {
    #[doc = "Bit 31"]
    #[inline(always)]
    pub fn pp_enable(&self) -> PP_ENABLE_R {
        PP_ENABLE_R::new(((self.bits >> 31) & 1) != 0)
    }
    #[doc = "Bits 16:19"]
    #[inline(always)]
    pub fn pp_shift(&self) -> PP_SHIFT_R {
        PP_SHIFT_R::new(((self.bits >> 16) & 0x0f) as u8)
    }
    #[doc = "Bits 0:11"]
    #[inline(always)]
    pub fn pp_time(&self) -> PP_TIME_R {
        PP_TIME_R::new((self.bits & 0x0fff) as u16)
    }
}
impl W {
    #[doc = "Bit 31"]
    #[inline(always)]
    pub fn pp_enable(&mut self) -> PP_ENABLE_W {
        PP_ENABLE_W { w: self }
    }
    #[doc = "Bits 16:19"]
    #[inline(always)]
    pub fn pp_shift(&mut self) -> PP_SHIFT_W {
        PP_SHIFT_W { w: self }
    }
    #[doc = "Bits 0:11"]
    #[inline(always)]
    pub fn pp_time(&mut self) -> PP_TIME_W {
        PP_TIME_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [spi_ext0]
(index.html) module"]
pub struct SPI_EXT0_SPEC;
impl crate::RegisterSpec for SPI_EXT0_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [spi_ext0::R]
(R) reader structure"]
impl crate::Readable for SPI_EXT0_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [spi_ext0::W]
(W) writer structure"]
impl crate::Writable for SPI_EXT0_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets SPI_EXT0 to value 0"]
impl crate::Resettable for SPI_EXT0_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
